define((function () { 'use strict';

	var main = { foo: 42 };

	return main;

}));
